@@ -1,10 +1,11 @@
 package Mojolicious::Plugin::TtRenderer;
+{
+  $Mojolicious::Plugin::TtRenderer::VERSION = '1.21';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
 use base 'Mojolicious::Plugin';
 
 use Mojolicious::Plugin::TtRenderer::Engine;
@@ -20,6 +21,8 @@ sub register {
     $app->renderer->add_handler(tt => $tt);
 }
 
+local ($Mojolicious::Plugin::TtRenderer::VERSION) = ('devel') unless defined $Mojolicious::Plugin::TtRenderer::VERSION;
+
 1;
 __END__
 
@@ -52,6 +55,12 @@ L<Mojolicious::Plugin> and implements the following new ones.
 
 Register renderer in L<Mojolicious> application.
 
+=head1 EXTRA STASH VARIABLES
+
+The current controller instance can be accessed as C<c>.
+
+   [% c.req.headers.host %]
+
 =head1 SEE ALSO
 
 L<Mojolicious::Plugin::TtRenderer::Engine>, L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
